Package: WrightMap
Type: Package
Title: IRT Item-Person Map with 'ConQuest' Integration
Version: 1.5
Date: 2026-08-23
Authors@R: c(person(given = "David",
                    family = "Torres Irribarra",
                    role = c("aut", "cre"),
                    email = "david@torresirribarra.me"),
             person(given = "Rebecca",
                    family = "Freund",
                    role = "aut"),
             person(given = "Joshua A.",
                    family = "McGrane",
                    role = "ctb"))
Maintainer: David Torres Irribarra <david@torresirribarra.me>
Description: A powerful yet simple graphical tool available in the field of psychometrics is the Wright Map (also known as item maps or item-person maps), which presents the location of both respondents and items on the same scale. Wright Maps are commonly used to present the results of dichotomous or polytomous item response models. The 'WrightMap' package provides functions to create these plots from item parameters and person estimates stored as R objects. Although the package can be used in conjunction with any software used to estimate the IRT model (e.g. 'TAM', 'mirt', 'eRm' or 'IRToys' in 'R', or 'Stata', 'Mplus', etc.), 'WrightMap' features special integration with 'ConQuest' to facilitate reading and plotting its output directly. The 'wrightMap' function creates Wright Maps based on person estimates and item parameters produced by an item response analysis. The 'CQmodel' function reads output files created using 'ConQuest' software and creates a set of data frames for easy data manipulation, bundled in a 'CQmodel' object. The 'wrightMap' function can take a 'CQmodel' object as input or it can be used to create Wright Maps directly from data frames of person and item parameters.
License: BSD_2_clause + file LICENSE
Depends: R (>= 3.0.0)
Imports: methods, RColorBrewer
Encoding: UTF-8
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-08-23 12:02:04 UTC; dti
Author: David Torres Irribarra [aut, cre],
  Rebecca Freund [aut],
  Joshua A. McGrane [ctb]
Repository: CRAN
Date/Publication: 2026-08-23 15:10:12 UTC
Built: R 4.6.0; ; 2026-08-23 16:19:26 UTC; unix
