Wright Map
=========

IRT Item-Person Map with 'ConQuest' Integration

Package: WrightMap

Type: Package

Version: 1.4

Date: 2024-09-24

Author: David Torres Irribarra & Rebecca Freund

Maintainer: david@torresirribarra.me, rlfreund@berkeley.edu

Description: The wrightMap function creates Wright Maps based on person estimates and item parameters produced by an item response analysis. The CQmodel function reads output files created using ConQuest software and creates a set of data frames for easy data manipulation, bundled in a CQmodel object. The wrightMap function can take a CQmodel object as input or it can be used to create Wright Maps directly from data frames of person and item parameters.

License: BSD 2 clause

Acknowledgments: Our thanks to Ronli Diakow & Beth Ayers for all their feedback and help.
